summaryrefslogtreecommitdiff
path: root/pthread.h
diff options
context:
space:
mode:
Diffstat (limited to 'pthread.h')
-rw-r--r--pthread.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/pthread.h b/pthread.h
index 861a0e8..aa48b32 100644
--- a/pthread.h
+++ b/pthread.h
@@ -918,10 +918,12 @@ int pthread_attr_setschedparam (pthread_attr_t *attr,
* WaitForMultipleObjects
*
* on 'waitHandle' and a manually reset WIN32 Event
* used to implement pthread_cancel. The 'abstime'
* argument is simply passed to WaitForMultipleObjects.
*/
-int pthreadCancelableWait (HANDLE waitHandle, DWORD abstime);
+int pthreadCancelableWait (HANDLE waitHandle);
+int pthreadCancelableTimedWait (HANDLE waitHandle, DWORD timeout);
/*
* Thread-Safe C Runtime Library Mappings
@@ -918,10 +918,12 @@ int pthread_attr_setschedparam (pthread_attr_t *attr,
*
* on 'waitHandle' and a manually reset WIN32 Event
- * used to implement pthread_cancel. The 'abstime'
- * argument is simply passed to WaitForMultipleObjects.
+ * used to implement pthread_cancel. The 'timeout'
+ * argument to TimedWait is simply passed to
+ * WaitForMultipleObjects.
*/